@@ -64,21 +64,20 @@ class Connect(object):
         self.debug = bool(debug)
         if self.debug:
             print("DEBUG MODE: ON")
-        # adding this else block for jenkins to pypi testing purposes. mcs
-        else:
-          self.http = requests.session()
-          self.http.verify = True
+            
+        self.http = requests.session()
+        self.http.verify = True
 
-          self.server = server
-          self.base_url = server + '/rest'
-          self.login_url = server + '/NetdotLogin'
-          self.timeout = 10
-          self.retries = 3
-          self.version = __version__
-          self.http.headers.update({'User_Agent': 'Netdot::Client::REST/self.version',
-                                    'Accept': 'text/xml; version=1.0'})
-          # Call the _login() function
-          self._login(username, password)
+        self.server = server
+        self.base_url = server + '/rest'
+        self.login_url = server + '/NetdotLogin'
+        self.timeout = 10
+        self.retries = 3
+        self.version = __version__
+        self.http.headers.update({'User_Agent': 'Netdot::Client::REST/self.version',
+                                  'Accept': 'text/xml; version=1.0'})
+        # Call the _login() function
+        self._login(username, password)
 
     def _login(self, username, password):
         """
